Class: Google::Apis::FirebaseV1beta1::AddFirebaseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Overview

All fields are required.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddFirebaseRequest

Returns a new instance of AddFirebaseRequest.



40
41
42
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 40

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_idString

DEPRECATED. Instead, use product-specific REST APIs to work with the location of each resource in a Project. This field may be ignored, especially for newly provisioned projects after October 30, 2024. The ID of the Project' s "location for default Google Cloud resources", which are resources associated with Google App Engine. The location must be one of the available Google App Engine locations. Corresponds to the JSON property locationId

Returns:

  • (String)


38
39
40
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 38

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45
46
47
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 45

def update!(**args)
  @location_id = args[:location_id] if args.key?(:location_id)
end