Class: Google::Apis::FirebaseV1beta1::AnalyticsProperty
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::AnalyticsProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
Details of a Google Analytics property
Instance Attribute Summary collapse
-
#analytics_account_id ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the Google Analytics property associated with the specified
FirebaseProject. -
#id ⇒ String
The globally unique, Google-assigned identifier of the Google Analytics property associated with the specified
FirebaseProject.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AnalyticsProperty
constructor
A new instance of AnalyticsProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AnalyticsProperty
Returns a new instance of AnalyticsProperty.
197 198 199 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analytics_account_id ⇒ String
Output only. The ID of the Google Analytics account for the Google Analytics property associated with the specified
FirebaseProject.
Corresponds to the JSON property analyticsAccountId
179 180 181 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 179 def analytics_account_id @analytics_account_id end |
#display_name ⇒ String
The display name of the Google Analytics property associated with the
specified FirebaseProject.
Corresponds to the JSON property displayName
185 186 187 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 185 def display_name @display_name end |
#id ⇒ String
The globally unique, Google-assigned identifier of the Google Analytics
property associated with the specified FirebaseProject. If you called
AddGoogleAnalytics to link the
FirebaseProject with a Google Analytics account, the value in this id field
is the same as the ID of the property either specified or provisioned with
that call to AddGoogleAnalytics.
Corresponds to the JSON property id
195 196 197 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 195 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
202 203 204 205 206 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 202 def update!(**args) @analytics_account_id = args[:analytics_account_id] if args.key?(:analytics_account_id) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) end |