Class: Google::Apis::FirebaseV1beta1::FirebaseAppInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Overview

A high-level summary of an App.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirebaseAppInfo

Returns a new instance of FirebaseAppInfo.



536
537
538
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_key_idString

The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the App. Be aware that this value is the UID of the API key, not the keyString of the API key. The keyString is the value that can be found in the App's configuration artifact ( AndroidApp | IosApp | WebApp). If api_key_id is not set in requests to create the App (AndroidApp | IosApp | WebApp), then Firebase automatically associates an api_key_id with the App. This auto-associated key may be an existing valid key or, if no valid key exists, a new one will be provisioned. Corresponds to the JSON property apiKeyId

Returns:

  • (String)


486
487
488
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 486

def api_key_id
  @api_key_id
end

#app_idString

Output only. Immutable. The globally unique, Firebase-assigned identifier for the WebApp. This identifier should be treated as an opaque token, as the data format is not specified. Corresponds to the JSON property appId

Returns:

  • (String)


493
494
495
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 493

def app_id
  @app_id
end

#display_nameString

The user-assigned display name of the Firebase App. Corresponds to the JSON property displayName

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 498

def display_name
  @display_name
end

#expire_timeString

Output only. If the App has been removed from the Project, this is the timestamp of when the App is considered expired and will be permanently deleted. After this time, the App cannot be undeleted (that is, restored to the Project). This value is only provided if the App is in the DELETED state. Corresponds to the JSON property expireTime

Returns:

  • (String)


506
507
508
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 506

def expire_time
  @expire_time
end

#nameString

The resource name of the Firebase App, in the format: projects/PROJECT_ID / iosApps/APP_ID or projects/PROJECT_ID/androidApps/APP_ID or projects/ PROJECT_ID/webApps/APP_ID Corresponds to the JSON property name

Returns:

  • (String)


513
514
515
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 513

def name
  @name
end

#namespaceString

Output only. Immutable. The platform-specific identifier of the App. Note: For most use cases, use appId, which is the canonical, globally unique identifier for referencing an App. This string is derived from a native identifier for each platform: packageName for an AndroidApp, bundleId for an IosApp, and webId for a WebApp. Its contents should be treated as opaque, as the native identifier format may change as platforms evolve. This string is only unique within a FirebaseProject and its associated Apps. Corresponds to the JSON property namespace

Returns:

  • (String)


524
525
526
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 524

def namespace
  @namespace
end

#platformString

The platform of the Firebase App. Corresponds to the JSON property platform

Returns:

  • (String)


529
530
531
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 529

def platform
  @platform
end

#stateString

Output only. The lifecycle state of the App. Corresponds to the JSON property state

Returns:

  • (String)


534
535
536
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 534

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



541
542
543
544
545
546
547
548
549
550
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 541

def update!(**args)
  @api_key_id = args[:api_key_id] if args.key?(:api_key_id)
  @app_id = args[:app_id] if args.key?(:app_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @namespace = args[:namespace] if args.key?(:namespace)
  @platform = args[:platform] if args.key?(:platform)
  @state = args[:state] if args.key?(:state)
end