Class: Google::Apis::FirebaseV1beta1::FirebaseManagementService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::FirebaseV1beta1::FirebaseManagementService
- Defined in:
- lib/google/apis/firebase_v1beta1/service.rb
Overview
Firebase Management API
The Firebase Management API enables programmatic setup and management of Firebase projects, including a project's Firebase resources and Firebase apps.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://firebase.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#add_project_firebase(project, add_firebase_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Adds Firebase resources and enables Firebase services in the specified existing Google Cloud
Project. -
#add_project_google_analytics(parent, add_google_analytics_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Links the specified FirebaseProject with an existing Google Analytics account.
-
#create_project_android_app(parent, android_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Requests the creation of a new AndroidApp in the specified FirebaseProject.
-
#create_project_android_app_sha(parent, sha_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ShaCertificate
Adds a ShaCertificate to the specified AndroidApp.
-
#create_project_ios_app(parent, ios_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Requests the creation of a new IosApp in the specified FirebaseProject.
-
#create_project_web_app(parent, web_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Requests the creation of a new WebApp in the specified FirebaseProject.
-
#delete_project_android_app_sha(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Empty
Removes a ShaCertificate from the specified AndroidApp.
-
#finalize_default_location(parent, finalize_default_location_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
DECOMMISSIONED. If called, this endpoint will return a 404 error. Instead, use the applicable resource-specific REST API to set the location for each resource used in your Project. Sets the "location for default Google Cloud resources" for the specified FirebaseProject.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Gets the latest state of a long-running operation.
-
#get_project(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::FirebaseProject
Gets the specified FirebaseProject.
-
#get_project_admin_sdk_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AdminSdkConfig
Gets the configuration artifact associated with the specified FirebaseProject, which can be used by servers to simplify initialization.
-
#get_project_analytics_details(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AnalyticsDetails
Gets the Google Analytics details currently associated with the specified FirebaseProject.
-
#get_project_android_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AndroidApp
Gets the specified AndroidApp.
-
#get_project_android_app_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AndroidAppConfig
Gets the configuration artifact associated with the specified AndroidApp.
-
#get_project_ios_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::IosApp
Gets the specified IosApp.
-
#get_project_ios_app_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::IosAppConfig
Gets the configuration artifact associated with the specified IosApp.
-
#get_project_web_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::WebApp
Gets the specified WebApp.
-
#get_project_web_app_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::WebAppConfig
Gets the configuration artifact associated with the specified WebApp.
-
#initialize ⇒ FirebaseManagementService
constructor
A new instance of FirebaseManagementService.
-
#list_available_projects(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListAvailableProjectsResponse
Lists each Google Cloud
Projectthat can have Firebase resources added and Firebase services enabled. -
#list_project_android_app_shas(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListShaCertificatesResponse
Lists the SHA-1 and SHA-256 certificates for the specified AndroidApp.
-
#list_project_android_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListAndroidAppsResponse
Lists each AndroidApp associated with the specified FirebaseProject.
-
#list_project_available_locations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListAvailableLocationsResponse
DECOMMISSIONED. If called, this endpoint will return a 404 error. Instead, use the applicable resource-specific REST API (or associated documentation, as needed) to determine valid locations for each resource used in your Project. Lists the valid "locations for default Google Cloud resources" for the specified Project (including a FirebaseProject).
-
#list_project_ios_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListIosAppsResponse
Lists each IosApp associated with the specified FirebaseProject.
-
#list_project_web_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListWebAppsResponse
Lists each WebApp associated with the specified FirebaseProject.
-
#list_projects(page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListFirebaseProjectsResponse
Lists each FirebaseProject accessible to the caller.
-
#patch_project(name, firebase_project_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::FirebaseProject
Updates the attributes of the specified FirebaseProject.
-
#patch_project_android_app(name, android_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AndroidApp
Updates the attributes of the specified AndroidApp.
-
#patch_project_ios_app(name, ios_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::IosApp
Updates the attributes of the specified IosApp.
-
#patch_project_web_app(name, web_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::WebApp
Updates the attributes of the specified WebApp.
-
#remove_android_app(name, remove_android_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Removes the specified AndroidApp from the FirebaseProject.
-
#remove_ios_app(name, remove_ios_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Removes the specified IosApp from the FirebaseProject.
-
#remove_project_analytics(parent, remove_analytics_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Empty
Unlinks the specified FirebaseProject from its Google Analytics account.
-
#remove_web_app(name, remove_web_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Removes the specified WebApp from the FirebaseProject.
-
#search_project_apps(parent, filter: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::SearchFirebaseAppsResponse
Lists all available Apps for the specified FirebaseProject.
-
#undelete_android_app(name, undelete_android_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Restores the specified AndroidApp to the FirebaseProject.
-
#undelete_ios_app(name, undelete_ios_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Restores the specified IosApp to the FirebaseProject.
-
#undelete_web_app(name, undelete_web_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Restores the specified WebApp to the FirebaseProject.
Constructor Details
#initialize ⇒ FirebaseManagementService
Returns a new instance of FirebaseManagementService.
48 49 50 51 52 53 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-firebase_v1beta1', client_version: Google::Apis::FirebaseV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#add_project_firebase(project, add_firebase_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Adds Firebase resources and enables Firebase services in the specified
existing Google Cloud Project. Since a FirebaseProject is actually also a Google
Cloud Project, a FirebaseProject has the same underlying Google Cloud
identifiers (projectNumber and projectId). This allows for easy interop
with Google APIs. The result of this call is an Operation. Poll the Operation to track the provisioning process by calling
GetOperation until done is
true. When done is true, the Operation has either succeeded or failed.
If the Operation succeeded, its response is set to a FirebaseProject; if the Operation
failed, its error is set
to a google.rpc.Status. The Operation is automatically deleted after
completion, so there is no need to call DeleteOperation. This method does not
modify any billing account information on the underlying Google Cloud Project
. To call AddFirebase, a project member or service account must have the
following permissions (the IAM roles of Editor and Owner contain these
permissions): firebase.projects.update, resourcemanager.projects.get,
serviceusage.services.enable, and serviceusage.services.get.
177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 177 def add_project_firebase(project, add_firebase_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+project}:addFirebase', ) command.request_representation = Google::Apis::FirebaseV1beta1::AddFirebaseRequest::Representation command.request_object = add_firebase_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['project'] = project unless project.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_project_google_analytics(parent, add_google_analytics_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Links the specified FirebaseProject with an existing Google Analytics account. Using this call, you can either: - Specify
an analyticsAccountId to provision a new Google Analytics property within
the specified account and associate the new property with the FirebaseProject
. - Specify an existing analyticsPropertyId to associate the property with
the FirebaseProject. Note that when you call AddGoogleAnalytics: 1. The
first check determines if any existing data streams in the Google Analytics
property correspond to any existing Firebase Apps in the FirebaseProject (
based on the packageName or bundleId associated with the data stream).
Then, as applicable, the data streams and apps are linked. Note that this auto-
linking only applies to AndroidApps and IosApps. 2. If no corresponding
data streams are found for the Firebase Apps, new data streams are provisioned
in the Google Analytics property for each of the Firebase Apps. Note that a
new data stream is always provisioned for a Web App even if it was previously
associated with a data stream in the Analytics property. Learn more about the
hierarchy and structure of Google Analytics accounts in the Analytics
documentation. The
result of this call is an Operation. Poll the
Operation to track the provisioning process by calling GetOperation until
done is true. When done
is true, the Operation has either succeeded or failed. If the Operation
succeeded, its response
is set to an AnalyticsDetails; if the Operation failed, its error is set to a google.rpc.Status. To
call AddGoogleAnalytics, a project member must be an Owner for the existing
FirebaseProject and have the Edit permission for the Google Analytics account. If the
FirebaseProject already has Google Analytics enabled, and you call
AddGoogleAnalytics using an analyticsPropertyId that's different from the
currently associated property, then the call will fail. Analytics may have
already been enabled in the Firebase console or by specifying timeZone and
regionCode in the call to AddFirebase.
244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 244 def add_project_google_analytics(parent, add_google_analytics_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:addGoogleAnalytics', ) command.request_representation = Google::Apis::FirebaseV1beta1::AddGoogleAnalyticsRequest::Representation command.request_object = add_google_analytics_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_android_app(parent, android_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Requests the creation of a new AndroidApp in the specified FirebaseProject.
The result of this call is an Operation which can be used to track the
provisioning process. The Operation is automatically deleted after
completion, so there is no need to call DeleteOperation.
597 598 599 600 601 602 603 604 605 606 607 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 597 def create_project_android_app(parent, android_app_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/androidApps', ) command.request_representation = Google::Apis::FirebaseV1beta1::AndroidApp::Representation command.request_object = android_app_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_android_app_sha(parent, sha_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ShaCertificate
Adds a ShaCertificate to the specified AndroidApp.
876 877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 876 def create_project_android_app_sha(parent, sha_certificate_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/sha', ) command.request_representation = Google::Apis::FirebaseV1beta1::ShaCertificate::Representation command.request_object = sha_certificate_object command.response_representation = Google::Apis::FirebaseV1beta1::ShaCertificate::Representation command.response_class = Google::Apis::FirebaseV1beta1::ShaCertificate command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_ios_app(parent, ios_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Requests the creation of a new IosApp in the specified FirebaseProject. The
result of this call is an Operation which can be used to track the
provisioning process. The Operation is automatically deleted after
completion, so there is no need to call DeleteOperation.
1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1117 def create_project_ios_app(parent, ios_app_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/iosApps', ) command.request_representation = Google::Apis::FirebaseV1beta1::IosApp::Representation command.request_object = ios_app_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_web_app(parent, web_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Requests the creation of a new WebApp in the specified FirebaseProject. The
result of this call is an Operation which can be used to track the
provisioning process. The Operation is automatically deleted after
completion, so there is no need to call DeleteOperation.
1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1395 def create_project_web_app(parent, web_app_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/webApps', ) command.request_representation = Google::Apis::FirebaseV1beta1::WebApp::Representation command.request_object = web_app_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_android_app_sha(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Empty
Removes a ShaCertificate from the specified AndroidApp.
915 916 917 918 919 920 921 922 923 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 915 def delete_project_android_app_sha(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::Empty::Representation command.response_class = Google::Apis::FirebaseV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#finalize_default_location(parent, finalize_default_location_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
DECOMMISSIONED. If called, this endpoint will return a 404 error.
Instead, use the applicable resource-specific REST API to set the location
for each resource used in your Project. Sets the "location for default
Google Cloud resources" for the specified FirebaseProject. This method creates
a Google App Engine application with a default Cloud Storage bucket, located in the
specified locationId. This location
must be one of the available App Engine locations. After the location for default Google Cloud resources
is finalized, or if it was already set, it cannot be changed. The location for
default Google Cloud resources for the specified FirebaseProject might
already be set because either the underlying Google Cloud Project already
has an App Engine application or FinalizeDefaultLocation was previously
called with a specified locationId. The result of this call is an
Operation, which can be used to track the
provisioning process. The response type of the Operation is google.protobuf.Empty. The
Operation can be polled by its name using GetOperation until done is true.
When done is true, the Operation has either succeeded or failed. If the
Operation has succeeded, its response will be set to a google.protobuf.Empty; if the Operation
has failed, its error will be set to a google.rpc.Status. The Operation is
automatically deleted after completion, so there is no need to call
DeleteOperation. All fields listed in the request body are
required. To call FinalizeDefaultLocation, a member must be an Owner of the
Project.
1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1078 def finalize_default_location(parent, finalize_default_location_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/defaultLocation:finalize', ) command.request_representation = Google::Apis::FirebaseV1beta1::FinalizeDefaultLocationRequest::Representation command.request_object = finalize_default_location_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
119 120 121 122 123 124 125 126 127 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 119 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::FirebaseProject
Gets the specified FirebaseProject.
278 279 280 281 282 283 284 285 286 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 278 def get_project(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::FirebaseProject::Representation command.response_class = Google::Apis::FirebaseV1beta1::FirebaseProject command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_admin_sdk_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AdminSdkConfig
Gets the configuration artifact associated with the specified FirebaseProject, which can be used by servers to simplify initialization. Typically, this configuration is used with the Firebase Admin SDK initializeApp command.
314 315 316 317 318 319 320 321 322 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 314 def get_project_admin_sdk_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::AdminSdkConfig::Representation command.response_class = Google::Apis::FirebaseV1beta1::AdminSdkConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_analytics_details(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AnalyticsDetails
Gets the Google Analytics details currently associated with the specified
FirebaseProject. If the FirebaseProject is not yet linked to Google
Analytics, then the response to GetAnalyticsDetails is NOT_FOUND.
349 350 351 352 353 354 355 356 357 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 349 def get_project_analytics_details(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::AnalyticsDetails::Representation command.response_class = Google::Apis::FirebaseV1beta1::AnalyticsDetails command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_android_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AndroidApp
Gets the specified AndroidApp.
634 635 636 637 638 639 640 641 642 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 634 def get_project_android_app(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::AndroidApp::Representation command.response_class = Google::Apis::FirebaseV1beta1::AndroidApp command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_android_app_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AndroidAppConfig
Gets the configuration artifact associated with the specified AndroidApp.
669 670 671 672 673 674 675 676 677 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 669 def get_project_android_app_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::AndroidAppConfig::Representation command.response_class = Google::Apis::FirebaseV1beta1::AndroidAppConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_ios_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::IosApp
Gets the specified IosApp.
1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1153 def get_project_ios_app(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::IosApp::Representation command.response_class = Google::Apis::FirebaseV1beta1::IosApp command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_ios_app_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::IosAppConfig
Gets the configuration artifact associated with the specified IosApp.
1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1188 def get_project_ios_app_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::IosAppConfig::Representation command.response_class = Google::Apis::FirebaseV1beta1::IosAppConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_web_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::WebApp
Gets the specified WebApp.
1431 1432 1433 1434 1435 1436 1437 1438 1439 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1431 def get_project_web_app(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::WebApp::Representation command.response_class = Google::Apis::FirebaseV1beta1::WebApp command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_web_app_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::WebAppConfig
Gets the configuration artifact associated with the specified WebApp.
1466 1467 1468 1469 1470 1471 1472 1473 1474 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1466 def get_project_web_app_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirebaseV1beta1::WebAppConfig::Representation command.response_class = Google::Apis::FirebaseV1beta1::WebAppConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_available_projects(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListAvailableProjectsResponse
Lists each Google Cloud Project that can have Firebase resources added and
Firebase services enabled. A Project will only be listed if: - The caller has
sufficient Google IAM permissions to call
AddFirebase. - The Project is not already a FirebaseProject. - The Project is
not in an Organization which has policies that prevent Firebase resources from
being added.
87 88 89 90 91 92 93 94 95 96 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 87 def list_available_projects(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/availableProjects', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListAvailableProjectsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListAvailableProjectsResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_android_app_shas(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListShaCertificatesResponse
Lists the SHA-1 and SHA-256 certificates for the specified AndroidApp.
951 952 953 954 955 956 957 958 959 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 951 def list_project_android_app_shas(parent, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/sha', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListShaCertificatesResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListShaCertificatesResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_android_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListAndroidAppsResponse
Lists each AndroidApp associated with the specified FirebaseProject. The
elements are returned in no particular order, but will be a consistent view of
the Apps when additional requests are made with a pageToken.
714 715 716 717 718 719 720 721 722 723 724 725 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 714 def list_project_android_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/androidApps', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListAndroidAppsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListAndroidAppsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_available_locations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListAvailableLocationsResponse
DECOMMISSIONED. If called, this endpoint will return a 404 error.
Instead, use the applicable resource-specific REST API (or associated
documentation, as needed) to determine valid locations for each resource used
in your Project. Lists the valid "locations for default Google Cloud
resources" for the specified Project (including a FirebaseProject). One of
these locations can be selected as the Project's location for default Google
Cloud resources, which is the geographical location where the Project's
resources associated with Google App Engine (such as the default Cloud
Firestore instance) will be provisioned by default. However, if the location
for default Google Cloud resources has already been set for the Project, then
this setting cannot be changed. This call checks for any possible location
restrictions for the specified Project and, thus, might return a
subset of all possible locations. To list all locations (regardless of any
restrictions), call the endpoint without specifying a unique project
identifier (that is, /v1beta1/parent=projects/-/listAvailableLocations).
To call ListAvailableLocations with a specified project, a member must be at
minimum a Viewer of the Project. Calls without a specified project do not
require any specific project permissions.
1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1014 def list_project_available_locations(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/availableLocations', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListAvailableLocationsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListAvailableLocationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_ios_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListIosAppsResponse
Lists each IosApp associated with the specified FirebaseProject. The elements
are returned in no particular order, but will be a consistent view of the Apps
when additional requests are made with a pageToken.
1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1233 def list_project_ios_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/iosApps', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListIosAppsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListIosAppsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_web_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListWebAppsResponse
Lists each WebApp associated with the specified FirebaseProject. The elements
are returned in no particular order, but will be a consistent view of the Apps
when additional requests are made with a pageToken.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1511 def list_project_web_apps(parent, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/webApps', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListWebAppsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListWebAppsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_projects(page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::ListFirebaseProjectsResponse
Lists each FirebaseProject accessible to the caller. The elements are returned
in no particular order, but they will be a consistent view of the Projects
when additional requests are made with a pageToken. This method is
eventually consistent with Project mutations, which means newly provisioned
Projects and recent modifications to existing Projects might not be reflected
in the set of Projects. The list will include only ACTIVE Projects. Use
GetFirebaseProject for consistent reads as well as for additional Project
details.
395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 395 def list_projects(page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/projects', ) command.response_representation = Google::Apis::FirebaseV1beta1::ListFirebaseProjectsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::ListFirebaseProjectsResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project(name, firebase_project_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::FirebaseProject
Updates the attributes of the specified FirebaseProject. All query parameters are required.
442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 442 def patch_project(name, firebase_project_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FirebaseV1beta1::FirebaseProject::Representation command.request_object = firebase_project_object command.response_representation = Google::Apis::FirebaseV1beta1::FirebaseProject::Representation command.response_class = Google::Apis::FirebaseV1beta1::FirebaseProject command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_android_app(name, android_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::AndroidApp
Updates the attributes of the specified AndroidApp.
761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 761 def patch_project_android_app(name, android_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FirebaseV1beta1::AndroidApp::Representation command.request_object = android_app_object command.response_representation = Google::Apis::FirebaseV1beta1::AndroidApp::Representation command.response_class = Google::Apis::FirebaseV1beta1::AndroidApp command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_ios_app(name, ios_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::IosApp
Updates the attributes of the specified IosApp.
1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1279 def patch_project_ios_app(name, ios_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FirebaseV1beta1::IosApp::Representation command.request_object = ios_app_object command.response_representation = Google::Apis::FirebaseV1beta1::IosApp::Representation command.response_class = Google::Apis::FirebaseV1beta1::IosApp command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_web_app(name, web_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::WebApp
Updates the attributes of the specified WebApp.
1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1557 def patch_project_web_app(name, web_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FirebaseV1beta1::WebApp::Representation command.request_object = web_app_object command.response_representation = Google::Apis::FirebaseV1beta1::WebApp::Representation command.response_class = Google::Apis::FirebaseV1beta1::WebApp command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_android_app(name, remove_android_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Removes the specified AndroidApp from the FirebaseProject.
800 801 802 803 804 805 806 807 808 809 810 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 800 def remove_android_app(name, remove_android_app_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:remove', ) command.request_representation = Google::Apis::FirebaseV1beta1::RemoveAndroidAppRequest::Representation command.request_object = remove_android_app_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_ios_app(name, remove_ios_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Removes the specified IosApp from the FirebaseProject.
1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1318 def remove_ios_app(name, remove_ios_app_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:remove', ) command.request_representation = Google::Apis::FirebaseV1beta1::RemoveIosAppRequest::Representation command.request_object = remove_ios_app_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_project_analytics(parent, remove_analytics_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Empty
Unlinks the specified FirebaseProject from its Google Analytics account. This
call removes the association of the specified FirebaseProject with its
current Google Analytics property. However, this call does not delete the
Google Analytics resources, such as the Google Analytics property or any data
streams. These resources may be re-associated later to the FirebaseProject
by calling AddGoogleAnalytics
and specifying the same analyticsPropertyId. For Android Apps and iOS Apps,
this call re-links data streams with their corresponding apps. However, for
Web Apps, this call provisions a new data stream for each Web App. To call
RemoveAnalytics, a project member must be an Owner for the FirebaseProject.
488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 488 def remove_project_analytics(parent, remove_analytics_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:removeAnalytics', ) command.request_representation = Google::Apis::FirebaseV1beta1::RemoveAnalyticsRequest::Representation command.request_object = remove_analytics_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Empty::Representation command.response_class = Google::Apis::FirebaseV1beta1::Empty command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_web_app(name, remove_web_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Removes the specified WebApp from the FirebaseProject.
1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1596 def remove_web_app(name, remove_web_app_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:remove', ) command.request_representation = Google::Apis::FirebaseV1beta1::RemoveWebAppRequest::Representation command.request_object = remove_web_app_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_apps(parent, filter: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::SearchFirebaseAppsResponse
Lists all available Apps for the specified FirebaseProject. This is a convenience method. Typically, interaction with an App should be done using the platform-specific service, but some tool use-cases require a summary of all known Apps (such as for App selector interfaces).
556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 556 def search_project_apps(parent, filter: nil, page_size: nil, page_token: nil, show_deleted: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}:searchApps', ) command.response_representation = Google::Apis::FirebaseV1beta1::SearchFirebaseAppsResponse::Representation command.response_class = Google::Apis::FirebaseV1beta1::SearchFirebaseAppsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['showDeleted'] = show_deleted unless show_deleted.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#undelete_android_app(name, undelete_android_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Restores the specified AndroidApp to the FirebaseProject.
838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 838 def undelete_android_app(name, undelete_android_app_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:undelete', ) command.request_representation = Google::Apis::FirebaseV1beta1::UndeleteAndroidAppRequest::Representation command.request_object = undelete_android_app_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#undelete_ios_app(name, undelete_ios_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Restores the specified IosApp to the FirebaseProject.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1356 def undelete_ios_app(name, undelete_ios_app_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:undelete', ) command.request_representation = Google::Apis::FirebaseV1beta1::UndeleteIosAppRequest::Representation command.request_object = undelete_ios_app_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#undelete_web_app(name, undelete_web_app_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseV1beta1::Operation
Restores the specified WebApp to the FirebaseProject.
1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 |
# File 'lib/google/apis/firebase_v1beta1/service.rb', line 1634 def undelete_web_app(name, undelete_web_app_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:undelete', ) command.request_representation = Google::Apis::FirebaseV1beta1::UndeleteWebAppRequest::Representation command.request_object = undelete_web_app_request_object command.response_representation = Google::Apis::FirebaseV1beta1::Operation::Representation command.response_class = Google::Apis::FirebaseV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |