Class: Google::Apis::FirebaseV1beta1::FirebaseProject
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::FirebaseProject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
A FirebaseProject is the top-level Firebase entity. It is the container for
Firebase Apps, Firebase Hosting sites, storage systems (Firebase Realtime
Database, Cloud Firestore, Cloud Storage buckets), and other Firebase and
Google Cloud resources. You create a FirebaseProject by calling AddFirebase
and specifying an existing Google Cloud Project. This adds Firebase resources to
the existing Google Cloud Project. Since a FirebaseProject is actually also
a Google Cloud Project, a FirebaseProject has the same underlying Google
Cloud identifiers (projectNumber and projectId). This allows for easy
interop with Google APIs.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
A set of user-defined annotations for the FirebaseProject.
-
#display_name ⇒ String
The user-assigned display name of the Project.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and it may be sent with update requests to ensure the client has an up-to-date value before proceeding.
-
#name ⇒ String
The resource name of the Project, in the format: projects/PROJECT_IDENTIFIER PROJECT_IDENTIFIER: the Project's
ProjectNumber(recommended) or itsProjectId. -
#project_id ⇒ String
Output only.
-
#project_number ⇒ Fixnum
Output only.
-
#resources ⇒ Google::Apis::FirebaseV1beta1::DefaultResources
DEPRECATED. _Auto-provisioning of these resources is changing, so this object no longer reliably provides information about the resources within the Project.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirebaseProject
constructor
A new instance of FirebaseProject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirebaseProject
Returns a new instance of FirebaseProject.
628 629 630 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
A set of user-defined annotations for the FirebaseProject. Learn more about
annotations in Google's AIP-128 standard. These annotations are intended solely for developers and client-
side tools. Firebase services will not mutate this annotations set.
Corresponds to the JSON property annotations
572 573 574 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 572 def annotations @annotations end |
#display_name ⇒ String
The user-assigned display name of the Project.
Corresponds to the JSON property displayName
577 578 579 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 577 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and it may be sent with update requests to ensure the client has an up-to-date
value before proceeding. Learn more about etag in Google's AIP-154 standard. This etag is
strongly validated.
Corresponds to the JSON property etag
586 587 588 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 586 def etag @etag end |
#name ⇒ String
The resource name of the Project, in the format: projects/PROJECT_IDENTIFIER
PROJECT_IDENTIFIER: the Project's ProjectNumber (recommended) or its ProjectId. Learn more about using
project identifiers in Google's AIP 2510 standard. Note that the value for PROJECT_IDENTIFIER in any response body
will be the ProjectId.
Corresponds to the JSON property name
597 598 599 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 597 def name @name end |
#project_id ⇒ String
Output only. Immutable. A user-assigned unique identifier for the Project.
This identifier may appear in URLs or names for some Firebase resources
associated with the Project, but it should generally be treated as a
convenience alias to reference the Project.
Corresponds to the JSON property projectId
605 606 607 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 605 def project_id @project_id end |
#project_number ⇒ Fixnum
Output only. Immutable. The globally unique, Google-assigned canonical
identifier for the Project. Use this identifier when configuring integrations
and/or making API calls to Firebase or third-party services.
Corresponds to the JSON property projectNumber
612 613 614 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 612 def project_number @project_number end |
#resources ⇒ Google::Apis::FirebaseV1beta1::DefaultResources
DEPRECATED. Auto-provisioning of these resources is changing, so this
object no longer reliably provides information about the resources within the
Project. Instead, retrieve information about each resource directly from its
resource-specific API. The default auto-provisioned resources associated with
the Project.
Corresponds to the JSON property resources
621 622 623 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 621 def resources @resources end |
#state ⇒ String
Output only. The lifecycle state of the Project.
Corresponds to the JSON property state
626 627 628 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 626 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
633 634 635 636 637 638 639 640 641 642 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 633 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @project_number = args[:project_number] if args.key?(:project_number) @resources = args[:resources] if args.key?(:resources) @state = args[:state] if args.key?(:state) end |