Class: Google::Apis::FirebaseV1beta1::IosApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Overview

Details of a Firebase App for iOS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IosApp

Returns a new instance of IosApp.



737
738
739
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 737

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_key_idString

The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the IosApp. Be aware that this value is the UID of the API key, not the keyString of the API key. The keyString is the value that can be found in the App's configuration artifact. If api_key_id is not set in requests to iosApps.Create, then Firebase automatically associates an api_key_id with the IosApp. This auto-associated key may be an existing valid key or, if no valid key exists, a new one will be provisioned. In patch requests, api_key_id cannot be set to an empty value, and the new UID must have no restrictions or only have restrictions that are valid for the associated IosApp. We recommend using the Google Cloud Console to manage API keys. Corresponds to the JSON property apiKeyId

Returns:

  • (String)


665
666
667
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 665

def api_key_id
  @api_key_id
end

#app_idString

Output only. Immutable. The globally unique, Firebase-assigned identifier for the IosApp. This identifier should be treated as an opaque token, as the data format is not specified. Corresponds to the JSON property appId

Returns:

  • (String)


672
673
674
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 672

def app_id
  @app_id
end

#app_store_idString

The automatically generated Apple ID assigned to the iOS app by Apple in the iOS App Store. Corresponds to the JSON property appStoreId

Returns:

  • (String)


678
679
680
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 678

def app_store_id
  @app_store_id
end

#bundle_idString

Immutable. The canonical bundle ID of the iOS app as it would appear in the iOS AppStore. Corresponds to the JSON property bundleId

Returns:

  • (String)


684
685
686
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 684

def bundle_id
  @bundle_id
end

#display_nameString

The user-assigned display name for the IosApp. Corresponds to the JSON property displayName

Returns:

  • (String)


689
690
691
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 689

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and it may be sent with update requests to ensure the client has an up-to-date value before proceeding. Learn more about etag in Google's AIP-154 standard. This etag is strongly validated. Corresponds to the JSON property etag

Returns:

  • (String)


698
699
700
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 698

def etag
  @etag
end

#expire_timeString

Output only. If the App has been removed from the Project, this is the timestamp of when the App is considered expired and will be permanently deleted. After this time, the App cannot be undeleted (that is, restored to the Project). This value is only provided if the App is in the DELETED state. Corresponds to the JSON property expireTime

Returns:

  • (String)


706
707
708
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 706

def expire_time
  @expire_time
end

#nameString

The resource name of the IosApp, in the format: projects/PROJECT_IDENTIFIER / iosApps/APP_ID * PROJECT_IDENTIFIER: the parent Project's ProjectNumber (recommended) or its ProjectId. Learn more about using project identifiers in Google's AIP 2510 standard. Note that the value for PROJECT_IDENTIFIER in any response body will be the ProjectId. * APP_ID: the globally unique, Firebase-assigned identifier for the App (see appId ). Corresponds to the JSON property name

Returns:

  • (String)


719
720
721
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 719

def name
  @name
end

#project_idString

Output only. Immutable. A user-assigned unique identifier of the parent FirebaseProject for the IosApp. Corresponds to the JSON property projectId

Returns:

  • (String)


725
726
727
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 725

def project_id
  @project_id
end

#stateString

Output only. The lifecycle state of the App. Corresponds to the JSON property state

Returns:

  • (String)


730
731
732
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 730

def state
  @state
end

#team_idString

The Apple Developer Team ID associated with the App in the App Store. Corresponds to the JSON property teamId

Returns:

  • (String)


735
736
737
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 735

def team_id
  @team_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



742
743
744
745
746
747
748
749
750
751
752
753
754
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 742

def update!(**args)
  @api_key_id = args[:api_key_id] if args.key?(:api_key_id)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_store_id = args[:app_store_id] if args.key?(:app_store_id)
  @bundle_id = args[:bundle_id] if args.key?(:bundle_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
  @team_id = args[:team_id] if args.key?(:team_id)
end