Class: Google::Apis::FirebaseV1beta1::RemoveIosAppRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveIosAppRequest

Returns a new instance of RemoveIosAppRequest.



1281
1282
1283
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

If set to true, and the App is not found, the request will succeed but no action will be taken on the server. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


1256
1257
1258
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1256

def allow_missing
  @allow_missing
end

#etagString

Checksum provided in the IosApp resource. If provided, this checksum ensures that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1263
1264
1265
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1263

def etag
  @etag
end

#immediateBoolean Also known as: immediate?

Determines whether to immediately delete the IosApp. If set to true, the App is immediately deleted from the Project and cannot be undeleted (that is, restored to the Project). If not set, defaults to false, which means the App will be set to expire in 30 days. Within the 30 days, the App may be restored to the Project using UndeleteIosApp Corresponds to the JSON property immediate

Returns:

  • (Boolean)


1272
1273
1274
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1272

def immediate
  @immediate
end

#validate_onlyBoolean Also known as: validate_only?

If set to true, the request is only validated. The App will not be removed. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1278
1279
1280
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1278

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1286
1287
1288
1289
1290
1291
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1286

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @etag = args[:etag] if args.key?(:etag)
  @immediate = args[:immediate] if args.key?(:immediate)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end