Class: Google::Apis::FirebaseV1beta1::UndeleteAndroidAppRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UndeleteAndroidAppRequest

Returns a new instance of UndeleteAndroidAppRequest.



1564
1565
1566
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Checksum provided in the AndroidApp resource. If provided, this checksum ensures that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1556
1557
1558
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1556

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

If set to true, the request is only validated. The App will not be undeleted. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1561
1562
1563
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1561

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1569
1570
1571
1572
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1569

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end