Class: Google::Apis::FirebaseV1beta1::UndeleteIosAppRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UndeleteIosAppRequest

Returns a new instance of UndeleteIosAppRequest.



1591
1592
1593
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Checksum provided in the IosApp resource. If provided, this checksum ensures that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1583
1584
1585
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1583

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

If set to true, the request is only validated. The App will not be undeleted. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1588
1589
1590
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1588

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1596
1597
1598
1599
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1596

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end