Class: Google::Apis::FirebaseV1beta1::WebApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb

Overview

Details of a Firebase App for the web.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebApp

Returns a new instance of WebApp.



1718
1719
1720
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_key_idString

The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the WebApp. Be aware that this value is the UID of the API key, not the keyString of the API key. The keyString is the value that can be found in the App's configuration artifact. If api_key_id is not set in requests to webApps.Create, then Firebase automatically associates an api_key_id with the WebApp. This auto-associated key may be an existing valid key or, if no valid key exists, a new one will be provisioned. In patch requests, api_key_id cannot be set to an empty value, and the new UID must have no restrictions or only have restrictions that are valid for the associated WebApp. We recommend using the Google Cloud Console to manage API keys. Corresponds to the JSON property apiKeyId

Returns:

  • (String)


1649
1650
1651
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1649

def api_key_id
  @api_key_id
end

#app_idString

Output only. Immutable. The globally unique, Firebase-assigned identifier for the WebApp. This identifier should be treated as an opaque token, as the data format is not specified. Corresponds to the JSON property appId

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1656

def app_id
  @app_id
end

#app_urlsArray<String>

The URLs where the WebApp is hosted. Corresponds to the JSON property appUrls

Returns:

  • (Array<String>)


1661
1662
1663
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1661

def app_urls
  @app_urls
end

#display_nameString

The user-assigned display name for the WebApp. Corresponds to the JSON property displayName

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1666

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and it may be sent with update requests to ensure the client has an up-to-date value before proceeding. Learn more about etag in Google's AIP-154 standard. This etag is strongly validated. Corresponds to the JSON property etag

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1675

def etag
  @etag
end

#expire_timeString

Output only. If the App has been removed from the Project, this is the timestamp of when the App is considered expired and will be permanently deleted. After this time, the App cannot be undeleted (that is, restored to the Project). This value is only provided if the App is in the DELETED state. Corresponds to the JSON property expireTime

Returns:

  • (String)


1683
1684
1685
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1683

def expire_time
  @expire_time
end

#nameString

The resource name of the WebApp, in the format: projects/PROJECT_IDENTIFIER / webApps/APP_ID * PROJECT_IDENTIFIER: the parent Project's ProjectNumber (recommended) or its ProjectId. Learn more about using project identifiers in Google's AIP 2510 standard. Note that the value for PROJECT_IDENTIFIER in any response body will be the ProjectId. * APP_ID: the globally unique, Firebase-assigned identifier for the App (see appId ). Corresponds to the JSON property name

Returns:

  • (String)


1696
1697
1698
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1696

def name
  @name
end

#project_idString

Output only. Immutable. A user-assigned unique identifier of the parent FirebaseProject for the WebApp. Corresponds to the JSON property projectId

Returns:

  • (String)


1702
1703
1704
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1702

def project_id
  @project_id
end

#stateString

Output only. The lifecycle state of the App. Corresponds to the JSON property state

Returns:

  • (String)


1707
1708
1709
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1707

def state
  @state
end

#web_idString

Output only. Immutable. A unique, Firebase-assigned identifier for the WebApp . This identifier is only used to populate the namespace value for the WebApp. For most use cases, use appId to identify or reference the App. The webId value is only unique within a FirebaseProject and its associated Apps. Corresponds to the JSON property webId

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1716

def web_id
  @web_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1723

def update!(**args)
  @api_key_id = args[:api_key_id] if args.key?(:api_key_id)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_urls = args[:app_urls] if args.key?(:app_urls)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
  @web_id = args[:web_id] if args.key?(:web_id)
end