Class: Google::Apis::FirebaseV1beta1::AdminSdkConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::AdminSdkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#database_url ⇒ String
DEPRECATED. _Instead, find the URL of the default Realtime Database instance using the list endpoint within the Firebase Realtime Database REST API.
-
#location_id ⇒ String
DEPRECATED. _Instead, use product-specific REST APIs to find the location of each resource in a Project.
-
#project_id ⇒ String
Immutable.
-
#storage_bucket ⇒ String
DEPRECATED. _Instead, find the name of the default Cloud Storage for Firebase bucket using the list endpoint within the Cloud Storage for Firebase REST API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdminSdkConfig
constructor
A new instance of AdminSdkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdminSdkConfig
Returns a new instance of AdminSdkConfig.
128 129 130 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_url ⇒ String
DEPRECATED. Instead, find the URL of the default Realtime Database
instance using the list endpoint within the Firebase Realtime Database REST API. If the default instance
for the Project has not yet been provisioned, the return might not contain a
default instance. Note that the config that's generated for the Firebase
console or the Firebase CLI uses the Realtime Database endpoint to populate
this value for that config. The URL of the default Firebase Realtime Database
instance.
Corresponds to the JSON property databaseURL
94 95 96 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 94 def database_url @database_url end |
#location_id ⇒ String
DEPRECATED. Instead, use product-specific REST APIs to find the location
of each resource in a Project. This field may not be populated, especially for
newly provisioned projects after October 30, 2024. The ID of the Project's "
location for default Google Cloud resources", which are resources associated
with Google App Engine. The location is one of the available App Engine
locations. This field is
omitted if the location for default Google Cloud resources has not been set.
Corresponds to the JSON property locationId
106 107 108 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 106 def location_id @location_id end |
#project_id ⇒ String
Immutable. A user-assigned unique identifier for the FirebaseProject. This
identifier may appear in URLs or names for some Firebase resources associated
with the Project, but it should generally be treated as a convenience alias to
reference the Project.
Corresponds to the JSON property projectId
114 115 116 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 114 def project_id @project_id end |
#storage_bucket ⇒ String
DEPRECATED. _Instead, find the name of the default Cloud Storage for
Firebase bucket using the list endpoint within the Cloud
Storage for Firebase REST API. If the default bucket for the Project has not
yet been provisioned, the return might not contain a default bucket. Note that
the config that's generated for the Firebase console or the Firebase CLI uses
the Cloud Storage for Firebase endpoint to populate this value for that config.
_ The name of the default Cloud Storage for Firebase bucket.
Corresponds to the JSON property storageBucket
126 127 128 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 126 def storage_bucket @storage_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
133 134 135 136 137 138 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 133 def update!(**args) @database_url = args[:database_url] if args.key?(:database_url) @location_id = args[:location_id] if args.key?(:location_id) @project_id = args[:project_id] if args.key?(:project_id) @storage_bucket = args[:storage_bucket] if args.key?(:storage_bucket) end |