Class: Google::Apis::FirebaseV1beta1::AndroidApp
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::AndroidApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
Details of a Firebase App for Android.
Instance Attribute Summary collapse
-
#api_key_id ⇒ String
The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the
AndroidApp. -
#app_id ⇒ String
Output only.
-
#display_name ⇒ String
The user-assigned display name for the
AndroidApp. -
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and it may be sent with update requests to ensure the client has an up-to-date value before proceeding.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
The resource name of the AndroidApp, in the format: projects/ PROJECT_IDENTIFIER/androidApps/APP_ID * PROJECT_IDENTIFIER: the parent Project' s
ProjectNumber( recommended) or itsProjectId. -
#package_name ⇒ String
Immutable.
-
#project_id ⇒ String
Output only.
-
#sha1_hashes ⇒ Array<String>
The SHA1 certificate hashes for the AndroidApp.
-
#sha256_hashes ⇒ Array<String>
The SHA256 certificate hashes for the AndroidApp.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AndroidApp
constructor
A new instance of AndroidApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AndroidApp
Returns a new instance of AndroidApp.
300 301 302 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key_id ⇒ String
The globally unique, Google-assigned identifier (UID) for the Firebase API key
associated with the AndroidApp. Be aware that this value is the UID of the
API key, not the keyString of the API
key. The keyString is the value that can be found in the App's
configuration artifact. If
api_key_id is not set in requests to androidApps.Create, then Firebase automatically associates
an api_key_id with the AndroidApp. This auto-associated key may be an
existing valid key or, if no valid key exists, a new one will be provisioned.
In patch requests, api_key_id cannot be set to an empty value, and the new
UID must have no restrictions or only have restrictions that are valid for the
associated AndroidApp. We recommend using the Google Cloud Console to manage API keys.
Corresponds to the JSON property apiKeyId
229 230 231 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 229 def api_key_id @api_key_id end |
#app_id ⇒ String
Output only. Immutable. The globally unique, Firebase-assigned identifier for
the AndroidApp. This identifier should be treated as an opaque token, as the
data format is not specified.
Corresponds to the JSON property appId
236 237 238 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 236 def app_id @app_id end |
#display_name ⇒ String
The user-assigned display name for the AndroidApp.
Corresponds to the JSON property displayName
241 242 243 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 241 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and it may be sent with update requests to ensure the client has an up-to-date
value before proceeding. Learn more about etag in Google's AIP-154 standard. This etag is
strongly validated.
Corresponds to the JSON property etag
250 251 252 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 250 def etag @etag end |
#expire_time ⇒ String
Output only. If the App has been removed from the Project, this is the
timestamp of when the App is considered expired and will be permanently
deleted. After this time, the App cannot be undeleted (that is, restored to
the Project). This value is only provided if the App is in the DELETED state.
Corresponds to the JSON property expireTime
258 259 260 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 258 def expire_time @expire_time end |
#name ⇒ String
The resource name of the AndroidApp, in the format: projects/
PROJECT_IDENTIFIER/androidApps/APP_ID * PROJECT_IDENTIFIER: the parent Project'
s ProjectNumber (
recommended) or its ProjectId. Learn more about using project identifiers in Google's AIP 2510
standard. Note that the value for
PROJECT_IDENTIFIER in any response body will be the ProjectId. * APP_ID: the
globally unique, Firebase-assigned identifier for the App (see appId).
Corresponds to the JSON property name
271 272 273 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 271 def name @name end |
#package_name ⇒ String
Immutable. The canonical package name of the Android app as would appear in
the Google Play Developer Console.
Corresponds to the JSON property packageName
277 278 279 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 277 def package_name @package_name end |
#project_id ⇒ String
Output only. Immutable. A user-assigned unique identifier of the parent
FirebaseProject for the AndroidApp.
Corresponds to the JSON property projectId
283 284 285 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 283 def project_id @project_id end |
#sha1_hashes ⇒ Array<String>
The SHA1 certificate hashes for the AndroidApp.
Corresponds to the JSON property sha1Hashes
288 289 290 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 288 def sha1_hashes @sha1_hashes end |
#sha256_hashes ⇒ Array<String>
The SHA256 certificate hashes for the AndroidApp.
Corresponds to the JSON property sha256Hashes
293 294 295 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 293 def sha256_hashes @sha256_hashes end |
#state ⇒ String
Output only. The lifecycle state of the App.
Corresponds to the JSON property state
298 299 300 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 298 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 305 def update!(**args) @api_key_id = args[:api_key_id] if args.key?(:api_key_id) @app_id = args[:app_id] if args.key?(:app_id) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @package_name = args[:package_name] if args.key?(:package_name) @project_id = args[:project_id] if args.key?(:project_id) @sha1_hashes = args[:sha1_hashes] if args.key?(:sha1_hashes) @sha256_hashes = args[:sha256_hashes] if args.key?(:sha256_hashes) @state = args[:state] if args.key?(:state) end |