Class: Google::Apis::FirebaseV1beta1::DefaultResources
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::DefaultResources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
DEPRECATED. Auto-provisioning of these resources is changing, so this object no longer reliably provides information about the resources within the Project. Instead, retrieve information about each resource directly from its resource-specific API. The default auto-provisioned resources associated with the Project.
Instance Attribute Summary collapse
-
#hosting_site ⇒ String
Output only.
-
#location_id ⇒ String
Output only.
-
#realtime_database_instance ⇒ String
Output only.
-
#storage_bucket ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DefaultResources
constructor
A new instance of DefaultResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DefaultResources
Returns a new instance of DefaultResources.
415 416 417 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hosting_site ⇒ String
Output only. DEPRECATED. Instead, find the name of the default Firebase
Hosting site using ListSites within the Firebase Hosting REST API.
If the default Hosting site for the Project has not yet been provisioned, the
return might not contain a default site. The name of the default Firebase
Hosting site, in the format: PROJECT_ID Though rare, your projectId might
already be used as the name for an existing Hosting site in another project (
learn more about creating non-default, additional sites). In these cases, your projectId is
appended with a hyphen then five alphanumeric characters to create your
default Hosting site name. For example, if your projectId is myproject123,
your default Hosting site name might be: myproject123-a5c16
Corresponds to the JSON property hostingSite
369 370 371 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 369 def hosting_site @hosting_site end |
#location_id ⇒ String
Output only. DEPRECATED. Instead, use product-specific REST APIs to find
the location of each resource in a Project. This field may not be populated,
especially for newly provisioned projects after October 30, 2024. The ID of
the Project's "location for default Google Cloud resources", which are
resources associated with Google App Engine. The location is one of the
available Google App Engine locations. This field is omitted if the location for default Google
Cloud resources has not been set.
Corresponds to the JSON property locationId
382 383 384 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 382 def location_id @location_id end |
#realtime_database_instance ⇒ String
Output only. DEPRECATED. Instead, find the name of the default Realtime
Database instance using the list endpoint within the Firebase Realtime Database REST API. If the default
Realtime Database instance for a Project has not yet been provisioned, the
return might not contain a default instance. The default Firebase Realtime
Database instance name, in the format: PROJECT_ID Though rare, your projectId
might already be used as the name for an existing Realtime Database instance
in another project (learn more about database sharding). In these cases, your projectId is
appended with a hyphen then five alphanumeric characters to create your
default Realtime Database instance name. For example, if your projectId is
myproject123, your default database instance name might be: myproject123-
a5c16
Corresponds to the JSON property realtimeDatabaseInstance
400 401 402 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 400 def realtime_database_instance @realtime_database_instance end |
#storage_bucket ⇒ String
Output only. DEPRECATED. Instead, find the name of the default Cloud
Storage for Firebase bucket using the list endpoint within the
Cloud Storage for Firebase REST API. If the default bucket for the Project has
not yet been provisioned, the return might not contain a default bucket. The
name of the default Cloud Storage for Firebase bucket, in one of the following
formats: * If provisioned before October 30, 2024: PROJECT_ID.
firebasestorage.app * If provisioned on or after October 30, 2024:
PROJECT_ID.firebasestorage.app
Corresponds to the JSON property storageBucket
413 414 415 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 413 def storage_bucket @storage_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
420 421 422 423 424 425 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 420 def update!(**args) @hosting_site = args[:hosting_site] if args.key?(:hosting_site) @location_id = args[:location_id] if args.key?(:location_id) @realtime_database_instance = args[:realtime_database_instance] if args.key?(:realtime_database_instance) @storage_bucket = args[:storage_bucket] if args.key?(:storage_bucket) end |