Class: Google::Apis::FirebaseV1beta1::Location
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::Location
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
DEPRECATED. This Location is no longer used to determine Firebase resource locations. Instead, consult product documentation to determine valid locations for each resource used in your Project. A "location for default Google Cloud resources" that can be selected for a FirebaseProject. These are resources associated with Google App Engine.
Instance Attribute Summary collapse
-
#features ⇒ Array<String>
Products and services that are available in the location for default Google Cloud resources.
-
#location_id ⇒ String
The ID of the Project's location for default Google Cloud resources.
-
#type ⇒ String
Indicates whether the location for default Google Cloud resources is a regional or multi-regional location for data replication.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
1007 1008 1009 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#features ⇒ Array<String>
Products and services that are available in the location for default Google
Cloud resources.
Corresponds to the JSON property features
991 992 993 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 991 def features @features end |
#location_id ⇒ String
The ID of the Project's location for default Google Cloud resources. It will
be one of the available Google App Engine locations.
Corresponds to the JSON property locationId
998 999 1000 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 998 def location_id @location_id end |
#type ⇒ String
Indicates whether the location for default Google Cloud resources is a
regional or multi-regional location for data replication.
Corresponds to the JSON property type
1005 1006 1007 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1005 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1012 1013 1014 1015 1016 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1012 def update!(**args) @features = args[:features] if args.key?(:features) @location_id = args[:location_id] if args.key?(:location_id) @type = args[:type] if args.key?(:type) end |