Class: Google::Apis::FirebaseV1beta1::ProjectInfo
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::ProjectInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
A reference to a Google Cloud Project.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The user-assigned display name of the Google Cloud
Project, for example:My App. -
#location_id ⇒ String
DEPRECATED _Instead, use product-specific REST APIs to work with the location of each resource in a Project.
-
#project ⇒ String
The resource name of the Google Cloud
Projectto which Firebase resources can be added, in the format: projects/PROJECT_IDENTIFIER Refer to theFirebaseProjectnamefield for details about PROJECT_IDENTIFIER values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectInfo
constructor
A new instance of ProjectInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectInfo
Returns a new instance of ProjectInfo.
1166 1167 1168 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The user-assigned display name of the Google Cloud Project, for example: My
App.
Corresponds to the JSON property displayName
1143 1144 1145 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1143 def display_name @display_name end |
#location_id ⇒ String
DEPRECATED Instead, use product-specific REST APIs to work with the
location of each resource in a Project. This field may not be populated,
especially for newly provisioned projects after October 30, 2024. The ID of
the Project's "location for default Google Cloud resources". The location is
one of the available Google App Engine locations. Not all Projects will have this field populated. If
it is not populated, it means that the Project does not yet have a location
for default Google Cloud resources.
Corresponds to the JSON property locationId
1156 1157 1158 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1156 def location_id @location_id end |
#project ⇒ String
The resource name of the Google Cloud Project to which Firebase resources
can be added, in the format: projects/PROJECT_IDENTIFIER Refer to the
FirebaseProject name field for
details about PROJECT_IDENTIFIER values.
Corresponds to the JSON property project
1164 1165 1166 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1164 def project @project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1171 1172 1173 1174 1175 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1171 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @location_id = args[:location_id] if args.key?(:location_id) @project = args[:project] if args.key?(:project) end |