Class: Google::Apis::FirebaseV1beta1::RemoveWebAppRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::RemoveWebAppRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
If set to true, and the App is not found, the request will succeed but no action will be taken on the server.
-
#etag ⇒ String
Checksum provided in the WebApp resource.
-
#immediate ⇒ Boolean
(also: #immediate?)
Determines whether to immediately delete the WebApp.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If set to true, the request is only validated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveWebAppRequest
constructor
A new instance of RemoveWebAppRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveWebAppRequest
Returns a new instance of RemoveWebAppRequest.
1327 1328 1329 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1327 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
If set to true, and the App is not found, the request will succeed but no
action will be taken on the server.
Corresponds to the JSON property allowMissing
1302 1303 1304 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1302 def allow_missing @allow_missing end |
#etag ⇒ String
Checksum provided in the WebApp resource. If provided, this checksum ensures
that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
1309 1310 1311 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1309 def etag @etag end |
#immediate ⇒ Boolean Also known as: immediate?
Determines whether to immediately delete the WebApp. If set to true, the App
is immediately deleted from the Project and cannot be undeleted (that is,
restored to the Project). If not set, defaults to false, which means the App
will be set to expire in 30 days. Within the 30 days, the App may be restored
to the Project using UndeleteWebApp
Corresponds to the JSON property immediate
1318 1319 1320 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1318 def immediate @immediate end |
#validate_only ⇒ Boolean Also known as: validate_only?
If set to true, the request is only validated. The App will not be removed.
Corresponds to the JSON property validateOnly
1324 1325 1326 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1324 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1332 1333 1334 1335 1336 1337 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1332 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @etag = args[:etag] if args.key?(:etag) @immediate = args[:immediate] if args.key?(:immediate) @validate_only = args[:validate_only] if args.key?(:validate_only) end |