Class: Google::Apis::FirebaseV1beta1::UndeleteWebAppRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::UndeleteWebAppRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Checksum provided in the WebApp resource.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If set to true, the request is only validated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UndeleteWebAppRequest
constructor
A new instance of UndeleteWebAppRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UndeleteWebAppRequest
Returns a new instance of UndeleteWebAppRequest.
1618 1619 1620 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Checksum provided in the WebApp resource. If provided, this checksum ensures
that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
1610 1611 1612 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1610 def etag @etag end |
#validate_only ⇒ Boolean Also known as: validate_only?
If set to true, the request is only validated. The App will not be undeleted.
Corresponds to the JSON property validateOnly
1615 1616 1617 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1615 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1623 1624 1625 1626 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1623 def update!(**args) @etag = args[:etag] if args.key?(:etag) @validate_only = args[:validate_only] if args.key?(:validate_only) end |