Class: Google::Apis::FirebaseV1beta1::WebAppConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseV1beta1::WebAppConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebase_v1beta1/classes.rb,
lib/google/apis/firebase_v1beta1/representations.rb,
lib/google/apis/firebase_v1beta1/representations.rb
Overview
Configuration metadata of a single Firebase App for the web.
Instance Attribute Summary collapse
-
#api_key ⇒ String
The
keyStringof the API key associated with theWebApp. -
#app_id ⇒ String
Immutable.
-
#auth_domain ⇒ String
The domain Firebase Auth configures for OAuth redirects, in the format: PROJECT_ID.firebaseapp.com Corresponds to the JSON property
authDomain. -
#database_url ⇒ String
DEPRECATED. _Instead, find the URL of the default Realtime Database instance using the list endpoint within the Firebase Realtime Database REST API.
-
#location_id ⇒ String
DEPRECATED. _Instead, use product-specific REST APIs to find the location of each resource in a Project.
-
#measurement_id ⇒ String
The unique Google-assigned identifier of the Google Analytics web stream associated with the
WebApp. -
#messaging_sender_id ⇒ String
The sender ID for use with Firebase Cloud Messaging.
-
#project_id ⇒ String
Immutable.
-
#project_number ⇒ String
Output only.
-
#realtime_database_url ⇒ String
Optional.
-
#recaptcha_site_key ⇒ String
Optional.
-
#storage_bucket ⇒ String
DEPRECATED. _Instead, find the name of the default Cloud Storage for Firebase bucket using the list endpoint within the Cloud Storage for Firebase REST API.
-
#version ⇒ String
Version of the config specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WebAppConfig
constructor
A new instance of WebAppConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WebAppConfig
Returns a new instance of WebAppConfig.
1849 1850 1851 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key ⇒ String
1748 1749 1750 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1748 def api_key @api_key end |
#app_id ⇒ String
Immutable. The globally unique, Firebase-assigned identifier for the WebApp.
Corresponds to the JSON property appId
1753 1754 1755 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1753 def app_id @app_id end |
#auth_domain ⇒ String
The domain Firebase Auth configures for OAuth redirects, in the format:
PROJECT_ID.firebaseapp.com
Corresponds to the JSON property authDomain
1759 1760 1761 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1759 def auth_domain @auth_domain end |
#database_url ⇒ String
DEPRECATED. Instead, find the URL of the default Realtime Database
instance using the list endpoint within the Firebase Realtime Database REST API. If the default instance
for the Project has not yet been provisioned, the return might not contain a
default instance. Note that the config that's generated for the Firebase
console or the Firebase CLI uses the Realtime Database endpoint to populate
this value for that config. The URL of the default Firebase Realtime Database
instance.
Corresponds to the JSON property databaseURL
1772 1773 1774 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1772 def database_url @database_url end |
#location_id ⇒ String
DEPRECATED. Instead, use product-specific REST APIs to find the location
of each resource in a Project. This field may not be populated, especially for
newly provisioned projects after October 30, 2024. The ID of the Project's "
location for default Google Cloud resources", which are resources associated
with Google App Engine. The location is one of the available App Engine
locations. This field is
omitted if the location for default Google Cloud resources has not been set.
Corresponds to the JSON property locationId
1784 1785 1786 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1784 def location_id @location_id end |
#measurement_id ⇒ String
The unique Google-assigned identifier of the Google Analytics web stream
associated with the WebApp. Firebase SDKs use this ID to interact with
Google Analytics APIs. This field is only present if the WebApp is linked to
a web stream in a Google Analytics App + Web property. Learn more about this
ID and Google Analytics web streams in the Analytics documentation. To generate a measurementId
and link the WebApp with a Google Analytics web stream, call
AddGoogleAnalytics. For apps
using the Firebase JavaScript SDK v7.20.0 and later, Firebase dynamically
fetches the measurementId when your app initializes Analytics. Having this
ID in your config object is optional, but it does serve as a fallback in the
rare case that the dynamic fetch fails.
Corresponds to the JSON property measurementId
1800 1801 1802 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1800 def measurement_id @measurement_id end |
#messaging_sender_id ⇒ String
The sender ID for use with Firebase Cloud Messaging.
Corresponds to the JSON property messagingSenderId
1805 1806 1807 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1805 def messaging_sender_id @messaging_sender_id end |
#project_id ⇒ String
Immutable. A user-assigned unique identifier for the FirebaseProject.
Corresponds to the JSON property projectId
1810 1811 1812 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1810 def project_id @project_id end |
#project_number ⇒ String
Output only. Immutable. The globally unique, Google-assigned canonical
identifier for the Project. Use this identifier when configuring integrations
and/or making API calls to Google Cloud or third-party services.
Corresponds to the JSON property projectNumber
1817 1818 1819 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1817 def project_number @project_number end |
#realtime_database_url ⇒ String
Optional. Duplicate field for the URL of the default Realtime Database
instances (if the default instance has been provisioned). If the request asks
for the V2 config format, this field will be populated instead of
realtime_database_instance_uri.
Corresponds to the JSON property realtimeDatabaseUrl
1825 1826 1827 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1825 def realtime_database_url @realtime_database_url end |
#recaptcha_site_key ⇒ String
Optional. Recaptcha Enterprise site key associated with the Firebase App.
Corresponds to the JSON property recaptchaSiteKey
1830 1831 1832 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1830 def recaptcha_site_key @recaptcha_site_key end |
#storage_bucket ⇒ String
DEPRECATED. _Instead, find the name of the default Cloud Storage for
Firebase bucket using the list endpoint within the Cloud
Storage for Firebase REST API. If the default bucket for the Project has not
yet been provisioned, the return might not contain a default bucket. Note that
the config that's generated for the Firebase console or the Firebase CLI uses
the Cloud Storage for Firebase endpoint to populate this value for that config.
_ The name of the default Cloud Storage for Firebase bucket.
Corresponds to the JSON property storageBucket
1842 1843 1844 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1842 def storage_bucket @storage_bucket end |
#version ⇒ String
Version of the config specification.
Corresponds to the JSON property version
1847 1848 1849 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1847 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 |
# File 'lib/google/apis/firebase_v1beta1/classes.rb', line 1854 def update!(**args) @api_key = args[:api_key] if args.key?(:api_key) @app_id = args[:app_id] if args.key?(:app_id) @auth_domain = args[:auth_domain] if args.key?(:auth_domain) @database_url = args[:database_url] if args.key?(:database_url) @location_id = args[:location_id] if args.key?(:location_id) @measurement_id = args[:measurement_id] if args.key?(:measurement_id) @messaging_sender_id = args[:messaging_sender_id] if args.key?(:messaging_sender_id) @project_id = args[:project_id] if args.key?(:project_id) @project_number = args[:project_number] if args.key?(:project_number) @realtime_database_url = args[:realtime_database_url] if args.key?(:realtime_database_url) @recaptcha_site_key = args[:recaptcha_site_key] if args.key?(:recaptcha_site_key) @storage_bucket = args[:storage_bucket] if args.key?(:storage_bucket) @version = args[:version] if args.key?(:version) end |